@@ -6,8 +6,8 @@ from pipedash.processor import BaseProcessor
 
 class LessCompiler(BaseProcessor):
 
-    input_mime = 'text/less'
-    output_mime = 'text/css'
+    input_extension = 'less'
+    output_extension = 'css'
 
     @property
     def command(self):
