@@ -5,6 +5,6 @@ from pipedash.processor import BaseProcessor
 
 class CssminCompressor(BaseProcessor):
 
-    input_mime = 'text/css'
-    output_mime = 'text/css'
+    input_extension = 'css'
+    output_extension = 'css'
     command = ['cssmin']
