@@ -19,11 +19,11 @@ class BaseProcessor(object):
         raise NotImplementedError
 
     @property
-    def input_mime(self):
+    def input_extension(self):
         raise NotImplementedError
 
     @property
-    def output_mime(self):
+    def output_extension(self):
         raise NotImplementedError
 
     def execute_command(self, command):
