@@ -13,8 +13,8 @@ from pipedash.processor import BaseProcessor
 
 class NonZeroExitProcessor(BaseProcessor):
 
-    input_mime = 'text/javascript'
-    output_mime = 'text/javascript'
+    input_extension = 'css'
+    output_extension = 'css'
     command = ['bash', '-c', 'exit 1']
 
 
@@ -44,6 +44,6 @@ class TestInvalidProcessor(TestCase):
         self.processor = InvalidProcessor(self.file)
 
     def test_invalid_processor_raises_exception(self):
-        for attr in ['input_mime', 'output_mime', 'command']:
+        for attr in ['input_extension', 'output_extension', 'command']:
             with self.assertRaises(NotImplementedError):
                 getattr(self.processor, attr)
